@@ -37,11 +37,11 @@ static struct GSQLFE_ObjectInfo
   gint gda_data2;
 } l_objects[] =
 {
-  { "Views", GDA_Connection_GDCN_SCHEMA_VIEWS, GDA_Connection_no_CONSTRAINT},
+  { "Views", GDA_Connection_GDCN_SCHEMA_VIEWS, GDA_Connection_no_CONSTRAINT, 0, 0 },
   { "Tables", GDA_Connection_GDCN_SCHEMA_TABLES, GDA_Connection_no_CONSTRAINT, 0, 0},
   { "Indexes", GDA_Connection_GDCN_SCHEMA_INDEXES, GDA_Connection_no_CONSTRAINT, 0, 0 },
   { "Procedures", GDA_Connection_GDCN_SCHEMA_PROCS, GDA_Connection_no_CONSTRAINT, 0, 0 },
-  { NULL, 0, 0 }
+  { NULL, 0, 0, 0, 0 }
 };
 
 /* private functions */
@@ -79,7 +79,10 @@ refresh_grids (GtkWidget *w, gpointer data)
      first argument and the current browser as the second one */
   info = browser_get_current_window();
   if (info != NULL)
-    select_list_cb(GTK_WIDGET(info->list), (gpointer) info);
+    {
+      select_combo_cb(NULL, (gpointer) info);
+      select_list_cb(GTK_WIDGET(info->list), (gpointer) info);
+    }
 }
 
 static void
@@ -107,11 +110,12 @@ select_combo_cb (GtkWidget *w, gpointer data)
 	      while (position != GDA_RECORDSET_INVALID_POSITION &&
 		     !gda_recordset_eof(rowset))
 		{
-		  GDA_Field *field = gda_recordset_field_idx(rowset, 0);
+		  Gda_Field *field = gda_recordset_field_idx(rowset, 2);
 		  if (field != NULL)
 		    {
 		      GtkWidget *w = 
-			gtk_list_item_new_with_label(gda_stringify_value(bfr, sizeof(bfr)-1, field));
+			gtk_list_item_new_with_label(gda_stringify_value(bfr, 
+						     sizeof(bfr) - 1, field));
 		      gtk_container_add(GTK_CONTAINER(info->list), w);
 		      gtk_widget_show(w);
 		    }
@@ -120,6 +124,7 @@ select_combo_cb (GtkWidget *w, gpointer data)
 		}
 	      /* close the record set */
 	      gda_recordset_close(rowset);
+	      gda_recordset_free(rowset);
 	    }
 	  else ui_show_error("Error getting schema");
 	}
@@ -147,20 +152,24 @@ select_list_cb (GtkWidget *w, gpointer data)
 	      /* get object name */
 	      list_item = GTK_OBJECT(node->data);
 	      obj_name = gtk_object_get_data(list_item, glb_list_item_data_key);
+	      fprintf(stderr,"select_list_cb: obj_name = '%s'\n", obj_name);
 	      /* show object's description */
 	      rowset = gda_connection_open_schema(info->db, 
-				     schema->gda_data1,
-			             schema->gda_data2, obj_name);
+				                          schema->gda_data1,
+			                              schema->gda_data2, obj_name);
 	      if (rowset != NULL)
-		info->grid1 = grid_show_resultset(info->grid1, rowset,
-				     GTK_CONTAINER(info->grid_scroll1));
+		{
+		  info->grid1 = grid_show_resultset(info->grid1, rowset,
+						    GTK_CONTAINER(info->grid_scroll1));
+		  gda_recordset_close(rowset);
+		  gda_recordset_free(rowset);
+		}
 	      else
 		{
 		  info->grid1 = grid_new_empty(info->grid1, 
 					       GTK_CONTAINER(info->grid_scroll1));
 		  ui_show_error("Error fetching data");
 		}
-	      gda_recordset_close(rowset);
 	    }
 	}
     }
@@ -272,6 +281,8 @@ browser_new_window (GtkWidget *gdb, gpointer data)
 	      GtkWidget *li = gtk_list_item_new_with_label(l_objects[cnt].string);
 	      gtk_container_add(GTK_CONTAINER(GTK_COMBO(brw_info->combo)->list), li);
 	      gtk_widget_show(li);
+	      gtk_object_set_data(GTK_OBJECT(li), glb_list_item_data_key,
+				  (gchar *) l_objects[cnt].string);
 	    }
 	  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(brw_info->combo)->list), 
 			     "selection_changed",
@@ -312,9 +323,9 @@ browser_new_window (GtkWidget *gdb, gpointer data)
 	  gtk_widget_show(brw_info->grid_scroll1);
 	  brw_info->grid1 = grid_new_empty(NULL, GTK_CONTAINER(brw_info->grid_scroll1));
 	  /* register this window */
-	  gtk_notebook_set_page(GTK_NOTEBOOK(ui_get_work_area()), l_openconns);
 	  l_openwins = g_list_append(l_openwins, (gpointer) brw_info);
 	  gtk_widget_show(brw_info->tab);
+	  ui_set_notebook_page(GTK_NOTEBOOK(ui_get_work_area()), brw_info->tab);
 	  l_openconns++;
 	}
       else ui_show_error("Cannot allocate %d bytes", 
