@@ -31,7 +31,6 @@ dialog_clicked_cb(GnomeDialog *dialog, gint button_number,
                   gpointer data)
 {
   register gint cnt;
-  extern CORBA_ORB orb;
   switch (button_number)
     {
     case 0 : /* OK button */
@@ -56,7 +55,7 @@ dialog_clicked_cb(GnomeDialog *dialog, gint button_number,
 	        {
 		  gint rc;
 		  /* create driver connection */
-		  db = gda_connection_new(orb);
+		  db = gda_connection_new(glb_orb);
 		  db->provider = g_strdup(drv_str);
 		  rc = gda_connection_open(db, dbname, login, pwd);
 		  if (rc == 0)
