@@ -31,13 +31,14 @@ db_close_connection (GtkWidget *w, gpointer data)
   struct GSQLFE_ConnectionInfo *info = db_get_current_connection();
   if (info != NULL)
     {
-      if (!gda_connection_close(info->db))
+      if (gda_connection_close(info->db) >= 0)
         {
           gint current = 
               gtk_notebook_page_num(GTK_NOTEBOOK(ui_get_work_area()),
                                     info->tab);
           /* remove all related windows */
           browser_close_all(info->db);
+	  sql_builder_close_all(info->db);
           /* remove the connection itself */
           l_connections = g_list_remove(l_connections, (gpointer) info);
 	  gda_connection_free(info->db);
@@ -62,14 +63,16 @@ db_close_all_connections (GtkWidget *w, gpointer data)
       info = (struct GSQLFE_ConnectionInfo *) node->data;
       /* move to next item in list */
       node = g_list_next(node);
-      if (!gda_connection_close(info->db))
+      if (gda_connection_close(info->db) >= 0)
         {
           current = gtk_notebook_page_num(GTK_NOTEBOOK(ui_get_work_area()),
                                           info->tab);
           /* remove all related windows */
           browser_close_all(info->db);
+	  sql_builder_close_all(info->db);
           /* remove the connection itself */
           l_connections = g_list_remove(l_connections, (gpointer) info);
+	  gda_connection_free(info->db);
           g_free((gpointer) info);
           gtk_notebook_remove_page(GTK_NOTEBOOK(ui_get_work_area()), current);
           l_openconns--;
@@ -85,7 +88,8 @@ db_commit (GtkWidget *w, gpointer data)
   struct GSQLFE_ConnectionInfo *info = db_get_current_connection();
   if (info != NULL)
     {
-      ui_show_error("Not already implemented");
+      if (gda_connection_commit_transaction(info->db) != 0)
+	ui_show_error("Error on COMMIT");
     }
 }
 
@@ -114,14 +118,15 @@ db_exec_command (GtkWidget *w, gpointer data)
 				   GTK_CONTAINER(info->scrolled_window));
               gda_recordset_close(rowset);
 	      gda_recordset_free(rowset);
-	      gda_command_free(cmd);
               sql_store_command(query);
             }
           else ui_show_error("Error executing query");
+	  gda_command_free(cmd);
         }
     }
 }
 
+/* return current connection */
 struct GSQLFE_ConnectionInfo *
 db_get_current_connection (void)
 {
@@ -134,6 +139,7 @@ db_get_current_connection (void)
       while (node != NULL)
         {
           struct GSQLFE_BrowserInfo *brwinfo;
+	  struct GSQLFE_SQLBuilderInfo *sqlinfo;
           info = node->data;
           this_one = gtk_notebook_page_num(GTK_NOTEBOOK(ui_get_work_area()),
                                                 info->tab);
@@ -142,7 +148,11 @@ db_get_current_connection (void)
           /* try searching browser windows */
           brwinfo = browser_get_current_window();
           if (brwinfo && brwinfo->db == info->db)
-              return (info);
+	    return (info);
+	  /* try searching SQL builder windows */
+	  sqlinfo = sql_builder_get_current_window();
+	  if (sqlinfo && sqlinfo->db == info->db)
+	    return (info);
           node = g_list_next(node);
         }
     }
@@ -198,13 +208,13 @@ db_new_connection (Gda_Connection *gdb)
     {
       /* initialize connection structure */
       info->db = gdb;
-      info->tab = gtk_table_new(3, 2, FALSE);
+      info->tab = gtk_table_new(6, 2, FALSE);
       gtk_widget_show(info->tab);
       sprintf(label, "%s@%s", gda_connection_get_user(gdb),
                               gda_connection_get_dsn(gdb));
       gtk_notebook_append_page(GTK_NOTEBOOK(ui_get_work_area()), info->tab,
                                gtk_label_new(label));
-      gtk_notebook_set_page(GTK_NOTEBOOK(ui_get_work_area()), l_openconns);
+      ui_set_notebook_page(GTK_NOTEBOOK(ui_get_work_area()), info->tab);
       info->toolbar = ui_new_toolbar_in_table(info->tab, 0, 0, 2, 1);
       gnome_app_fill_toolbar(GTK_TOOLBAR(info->toolbar), sqltoolbar, NULL);
       info->cmd_win = ui_new_text_in_table(info->tab, 0, 1, 2, 2);
@@ -213,9 +223,9 @@ db_new_connection (Gda_Connection *gdb)
       gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(info->scrolled_window),
                                      GTK_POLICY_AUTOMATIC,
                                      GTK_POLICY_AUTOMATIC);
-      gtk_table_attach(GTK_TABLE(info->tab), info->scrolled_window, 0, 2, 2, 3,
+      gtk_table_attach(GTK_TABLE(info->tab), info->scrolled_window, 0, 2, 2, 6,
                        GTK_SHRINK | GTK_EXPAND | GTK_FILL,
-                       GTK_EXPAND | GTK_FILL,
+                       GTK_EXPAND | GTK_FILL | GTK_EXPAND,
                        3, 3);
       gtk_widget_show(info->scrolled_window);
       /* create grid */
@@ -246,7 +256,8 @@ db_rollback (GtkWidget *w, gpointer data)
   struct GSQLFE_ConnectionInfo *info = db_get_current_connection();
   if (info != NULL)
     {
-      ui_show_error("Not yet implemented");
+      if (gda_connection_rollback_transaction(info->db) != 0)
+	ui_show_error("Error on ROLLBACK");
     }
 }
 
@@ -257,6 +268,8 @@ db_start_transaction (GtkWidget *w, gpointer data)
   struct GSQLFE_ConnectionInfo *info = db_get_current_connection();
   if (info != NULL)
     {
-      ui_show_error("Not yet implemented");
+      if (gda_connection_begin_transaction(info->db) != 0)
+	ui_show_error("Error on BEGIN");
     }
 }
+
