@@ -31,10 +31,9 @@ clist_compare_function (GtkCList *list, gconstpointer p1, gconstpointer p2)
 static void
 select_column_cb (GtkWidget *w, gint col, gpointer data)
 {
-  gtk_clist_set_compare_func(GTK_CLIST(w), 
-			     (GtkCListCompareFunc) clist_compare_function);
-  gtk_clist_set_sort_type(GTK_CLIST(w), GTK_SORT_ASCENDING);
+  gtk_clist_freeze(GTK_CLIST(w));
   gtk_clist_sort(GTK_CLIST(w));
+  gtk_clist_thaw(GTK_CLIST(w));
 }
 
 static GtkWidget *
@@ -47,9 +46,12 @@ create_grid (gint cnt, gchar *titles[], GtkContainer *parent)
   gtk_clist_set_selection_mode(GTK_CLIST(grid), GTK_SELECTION_SINGLE);
   gtk_clist_moveto(GTK_CLIST(grid), 0, 0, 0.0, 0.0);
   gtk_clist_set_shadow_type(GTK_CLIST(grid), GTK_SHADOW_IN);
-  /* set grid for sorting purposes */
+  /* set grid for sorting */
   gtk_signal_connect(GTK_OBJECT(grid), "click_column",
 		     GTK_SIGNAL_FUNC(select_column_cb), NULL);
+  gtk_clist_set_compare_func(GTK_CLIST(grid), 
+			     (GtkCListCompareFunc) clist_compare_function);
+  gtk_clist_set_sort_type(GTK_CLIST(grid), GTK_SORT_ASCENDING);
   gtk_widget_show(grid);
   if (parent != NULL)
     gtk_container_add(parent, grid);
@@ -94,7 +96,7 @@ grid_show_resultset (GtkWidget *old_grid, Gda_Recordset *rowset,
              !gda_recordset_eof(rowset))
 	{
 	  GPtrArray *row;
-	  GDA_Field *field;
+	  Gda_Field *field;
 	  register int col;
 	  row = g_ptr_array_new();
 	  total_fields = gda_recordset_rowsize(rowset);
@@ -103,7 +105,7 @@ grid_show_resultset (GtkWidget *old_grid, Gda_Recordset *rowset,
 	    {
 	      for (cnt = 0; cnt < total_fields; cnt++)
 		{
-		  col_name = gda_recordset_field_idx(rowset, cnt)->name;
+		  col_name = gda_field_name(gda_recordset_field_idx(rowset, cnt));
 		  if (col_name != NULL)
 		    g_ptr_array_add(columns, (gconstpointer) col_name);
 		}
@@ -119,6 +121,7 @@ grid_show_resultset (GtkWidget *old_grid, Gda_Recordset *rowset,
 		{
 		  g_ptr_array_add(row, gda_stringify_value(0, 0, field));
 		  /* set column justification depending on field type */
+		  /*
 		  switch (field->cType)
 		    {
 		    case GDA_TypeBigint :
@@ -140,8 +143,9 @@ grid_show_resultset (GtkWidget *old_grid, Gda_Recordset *rowset,
 							 GTK_JUSTIFY_LEFT);
 		      break;
 		    }
+		  */
 		  gtk_clist_set_column_auto_resize(GTK_CLIST(grid), col, TRUE);
-		  gtk_clist_set_column_resizeable(GTK_CLIST(grid), col, TRUE);
+		  //gtk_clist_set_column_resizeable(GTK_CLIST(grid), col, TRUE);
 		}
 	    }
 	  gtk_clist_freeze(GTK_CLIST(grid));
