@@ -22,88 +22,106 @@
 #if !defined(_GNOME_SQL_FE_)
 #  define _GNOME_SQL_FE_ 0
 
-/* header files */
+/* GDA library */
 #include <gda-command.h>
 #include <gda-connection.h>
 #include <gda-field.h>
 #include <gda-recordset.h>
 #include <gda-server.h>
 
-/* data types */
-struct GSQLFE_ConnectionInfo
-{
-  Gda_Connection *db;
-  GtkWidget *tab;
-  GtkWidget *toolbar;
-  GtkWidget *cmd_win;
-  GtkWidget *scrolled_window;
-  GtkWidget *grid;
-};
-struct GSQLFE_BrowserInfo
-{
-  Gda_Connection *db;
-  GtkWidget *tab;
-  GtkWidget *toolbar;
-  GtkWidget *combo;
-  GtkWidget *scrolled_window;
-  GtkWidget *list;
-  GtkWidget *grid_scroll1;
-  GtkWidget *grid1;
-  GtkWidget *grid_scroll2;
-  GtkWidget *grid2;
-};
-
-/* configuration stuff */
+/* 
+ * configuration stuff 
+ */
 #define MAX_COMMAND_LIST 100		/* size of stored commands list */
 
 extern void app_init_gnome_session (void);
 extern void app_load_settings (void);
-
-/* callback functions */
 extern void app_save_settings (GtkWidget *, gpointer );
 
-extern void browser_new_window (GtkWidget *, gpointer );
+/* 
+ * connections 
+ */
+struct GSQLFE_ConnectionInfo
+{
+  Gda_Connection *db;
+  GtkWidget      *tab;
+  GtkWidget      *toolbar;
+  GtkWidget      *cmd_win;
+  GtkWidget      *scrolled_window;
+  GtkWidget      *grid;
+};
 
 extern void db_close_connection (GtkWidget *, gpointer );
 extern void db_close_all_connections (GtkWidget *, gpointer );
 extern void db_commit (GtkWidget *, gpointer );
 extern void db_exec_command (GtkWidget *, gpointer );
+extern struct GSQLFE_ConnectionInfo *db_get_current_connection (void);
+extern void db_new_connection (Gda_Connection *);
 extern void db_open_connection (GtkWidget *, gpointer );
 extern void db_rollback (GtkWidget *, gpointer );
 extern void db_set_trace (GtkWidget *, gpointer );
 extern void db_start_transaction (GtkWidget *, gpointer );
 
+/*
+ * object browser
+ */
+struct GSQLFE_BrowserInfo
+{
+  Gda_Connection *db;
+  GtkWidget      *tab;
+  GtkWidget      *toolbar;
+  GtkWidget      *combo;
+  GtkWidget      *scrolled_window;
+  GtkWidget      *list;
+  GtkWidget      *grid_scroll1;
+  GtkWidget      *grid1;
+  GtkWidget      *grid_scroll2;
+  GtkWidget      *grid2;
+};
+
+extern void browser_close_all (Gda_Connection *);
+struct GSQLFE_BrowserInfo *browser_get_current_window (void);
+extern void browser_new_window (GtkWidget *, gpointer );
+
+/*
+ * SQL builder
+ */
+struct GSQLFE_SQLBuilderInfo
+{
+  Gda_Connection *db;
+  GtkWidget      *tab;
+  GtkWidget      *toolbar;
+  GtkWidget      *combo;
+};
+
+extern void sql_builder_close_all (Gda_Connection *);
+extern struct GSQLFE_SQLBuilderInfo *sql_builder_get_current_window (void);
+extern gchar *sql_get_last_command (void);
 extern void sql_clear_window (GtkWidget *, gpointer );
 extern void sql_copy_text (GtkWidget *, gpointer );
 extern void sql_cut_text (GtkWidget *, gpointer );
 extern void sql_load_script (GtkWidget *, gpointer );
+extern void sql_new_builder (GtkWidget *, gpointer );
 extern void sql_paste_text (GtkWidget *, gpointer );
 extern void sql_refresh_grid (GtkWidget *, gpointer );
 extern void sql_run_script (GtkWidget *, gpointer );
 extern void sql_save_script (GtkWidget *, gpointer );
 extern void sql_select_command (GtkWidget *, gpointer );
+extern void                          sql_store_command (const gchar *);
 
-/* database functions */
-extern struct GSQLFE_ConnectionInfo *db_get_current_connection (void);
-extern void                          db_new_connection (Gda_Connection *);
-
-/* SQL functions */
-extern gchar *sql_get_last_command (void);
-extern void   sql_store_command (const gchar *);
-
-/* DB Grid functions */
+/* 
+ * DB Grid
+ */
 extern GtkWidget *grid_new_empty (GtkWidget *, GtkContainer *);
 extern GtkWidget *grid_show_resultset (GtkWidget *, Gda_Recordset *, GtkContainer *);
 
-/* object browser */
-extern void                browser_close_all (Gda_Connection *);
-struct GSQLFE_BrowserInfo *browser_get_current_window (void);
-
-/* UI helper functions */
-extern void       ui_fill_list (GtkList *, GList *);
-extern gchar     *ui_get_file_name (gchar *);
+/* 
+ * UI helper functions
+ */
+extern void ui_fill_list (GtkList *, GList *);
+extern gchar *ui_get_file_name (gchar *);
 extern GtkWidget *ui_get_work_area (void);
-extern void       ui_load_file_in_text (GtkText *, gchar *);
+extern void ui_load_file_in_text (GtkText *, gchar *);
 extern GtkWidget *ui_new_combo_in_table (GtkWidget *, gint , gint , gint , gint );
 extern GtkWidget *ui_new_entry_in_table (GtkWidget *, gchar *, gchar *, gint ,
                                         gint , gint , gint );
@@ -113,11 +131,27 @@ extern GtkWidget *ui_new_text_in_table (GtkWidget *, gint , gint ,
                                         gint , gint );
 extern GtkWidget *ui_new_toolbar_in_table (GtkWidget *, gint , gint , 
                                            gint , gint );
-extern void       ui_show_error (const gchar *, ...);
-                                         
-/* global variables */
+extern void ui_set_notebook_page (GtkNotebook *, GtkWidget *);
+extern void ui_show_error (const gchar *, ...);
+
+/*
+ * integrated text editor
+ */
+extern void editor_close_window (GtkWidget *, gpointer );
+extern void editor_open_window (GtkWidget *, gpointer );
+                       
+/*
+ * GDA log viewer
+ */
+extern void log_close_window (GtkWidget *, gpointer );
+extern void log_open_window (GtkWidget *, gpointer );
+                 
+/* 
+ * global variables 
+ */
 extern GnomeApp *glb_app;
 extern gchar *glb_list_item_data_key;
+extern CORBA_ORB glb_orb;
 
 #endif
 
