@@ -22,7 +22,7 @@
 /* global variables */
 GnomeApp *glb_app = NULL;
 GtkWidget *wContainer = NULL, *wWorkArea = NULL, *wStatusBar = NULL;
-CORBA_ORB orb;
+CORBA_ORB glb_orb;
 
 /* function definitions */
 static void prepare_app (void);
@@ -51,7 +51,7 @@ main (gint argc, gchar *argv[])
   CORBA_Environment ev;
   /* initialize CORBA stuff */
   CORBA_exception_init(&ev);
-  orb = gnome_CORBA_init("gsqlfe", "0.1", &argc, argv, 0, &ev);
+  glb_orb = gnome_CORBA_init("gsqlfe", "0.1", &argc, argv, 0, &ev);
   Exception(&ev);
   /* load application settings and create main window */
   app_init_gnome_session();
@@ -67,8 +67,8 @@ main (gint argc, gchar *argv[])
 /* callbacks */
 static void about_cb (GtkWidget *w, gpointer data)
 {
-  const gchar *authors[] = { "Rodrigo Moya <rmoya@chez.com>, User Interface",
-			     "Michael Lausch <michael@lausch.at>, GDA Interface",
+  const gchar *authors[] = { "Michael Lausch <michael@lausch.at>",
+			     "Rodrigo Moya <rmoya@chez.com>",
 			     NULL };
   GtkWidget *about = gnome_about_new(_("GNOME-SQL"), _("Front-End"),
 				     _("Copyright Rodrigo Moya (C) 1998"),
@@ -156,6 +156,9 @@ GnomeUIInfo databasemenu[] =
       N_("Start or stop database trace"),
       db_set_trace, NULL, NULL, GNOME_APP_PIXMAP_NONE,
       NULL, 0, 0, NULL },
+  { GNOME_APP_UI_ITEM, N_("SQL Builder"), N_("Construct SQL statements"),
+    sql_new_builder, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Begin Transaction"), N_("Begin new transaction"),
       db_start_transaction, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
@@ -168,6 +171,16 @@ GnomeUIInfo databasemenu[] =
       GNOME_STOCK_MENU_REVERT, 0, 0, NULL },
   GNOMEUIINFO_END
 };
+GnomeUIInfo toolsmenu[] =
+{
+  { GNOME_APP_UI_ITEM, N_("GDA logs"), N_("View GDA server log files"),
+    log_open_window, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    GNOME_STOCK_MENU_BOOK_RED, 0, 0, NULL },
+  { GNOME_APP_UI_ITEM, N_("Text editor"), N_("Open the internal text editor"),
+    editor_open_window, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    GNOME_STOCK_MENU_BOOK_RED, 0, 0, NULL },
+  GNOMEUIINFO_END
+};
 GnomeUIInfo optionsmenu[] =
 {
   { GNOME_APP_UI_ITEM, N_("Preferences..."), N_("Configure user preferences"),
@@ -202,6 +215,7 @@ GnomeUIInfo mainmenu[] =
   GNOMEUIINFO_SUBTREE(N_("Edit"), editmenu),
   GNOMEUIINFO_SUBTREE(N_("SQL"), sqlmenu),
   GNOMEUIINFO_SUBTREE(N_("Database"), databasemenu),
+  GNOMEUIINFO_SUBTREE(N_("Tools"), toolsmenu),
   GNOMEUIINFO_SUBTREE(N_("Options"), optionsmenu),
   GNOMEUIINFO_SUBTREE(N_("Help"), helpmenu),
   GNOMEUIINFO_END
@@ -216,6 +230,9 @@ GnomeUIInfo toolbar[] =
   { GNOME_APP_UI_ITEM, N_("Disconnect"), N_("Close current connection"),
     db_close_connection, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_PIXMAP_STOP, 0, 0, NULL },
+  { GNOME_APP_UI_ITEM, N_("GDA Logs"), N_("View GDA server log files"),
+    log_open_window, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    GNOME_STOCK_PIXMAP_BOOK_RED, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Preferences"), N_("Configure user preferences"),
     NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
