@@ -92,8 +92,8 @@ app_init_gnome_session (void)
   glb_SessionClient = gnome_master_client();
   gtk_signal_connect(GTK_OBJECT(glb_SessionClient), "save_yourself",
 		     GTK_SIGNAL_FUNC(save_yourself_cb), NULL);
-  //gtk_signal_connect(GTK_OBJECT(glb_SessionClient), "die_session",
-  //		     GTK_SIGNAL_FUNC(die_session_cb), NULL);
+  gtk_signal_connect(GTK_OBJECT(glb_SessionClient), "die",
+  		     GTK_SIGNAL_FUNC(die_session_cb), NULL);
 }
 
 
