@@ -103,15 +103,14 @@ void
 sql_load_script (GtkWidget *w, gpointer data)
 {
   struct GSQLFE_ConnectionInfo *info = db_get_current_connection();
-  if (info != NULL)
+  gchar *filename = ui_get_file_name("Select SQL Script");
+  if (filename != NULL)
     {
-      gchar *filename = ui_get_file_name("Select SQL Script");
-      if (filename != NULL)
-	{
-	  ui_load_file_in_text(GTK_TEXT(info->cmd_win), filename);
-	  /* free memory */
-	  g_free((gpointer) filename);
-	}
+      if (info != NULL)
+	ui_load_file_in_text(GTK_TEXT(info->cmd_win), filename);
+      else editor_open_window(NULL, filename);
+      /* free memory */
+      g_free((gpointer) filename);
     }
 }
 
@@ -136,16 +135,18 @@ sql_refresh_grid (GtkWidget *w, gpointer data)
           Gda_Command *cmd = gda_command_new();
           Gda_Recordset *rowset;
           gulong reccount;
-          gda_command_set_text(cmd, command);
           gda_command_set_connection(cmd, info->db);
+	  gda_command_set_text(cmd, command);
           rowset = gda_command_execute(command, &reccount, 0);
           if (rowset != NULL)
             {
               info->grid = grid_show_resultset(info->grid, rowset,
 					       GTK_CONTAINER(info->scrolled_window));
               gda_recordset_close(rowset);
+	      gda_recordset_free(rowset);
             }
           else ui_show_error("Error executing command");
+	  gda_command_free(cmd);
         }
     }
 }
@@ -188,30 +189,14 @@ sql_save_script (GtkWidget *w, gpointer data)
   struct GSQLFE_ConnectionInfo *info = db_get_current_connection();
   if (info != NULL)
     {
-      gchar *buffer, *filename;
-      buffer = gtk_editable_get_chars(GTK_EDITABLE(info->cmd_win), 0, 
-				      gtk_text_get_length(GTK_TEXT(info->cmd_win)));
-      if (buffer != NULL)
-	{
-	  /* prompt user for file name */
-	  filename = ui_get_file_name("Save SQL Buffer");
-	  if (filename != NULL)
-	    {
-	      FILE *file = fopen(filename, "w");
-	      if (file != NULL)
-		{
-		  fwrite(buffer, gtk_text_get_length(GTK_TEXT(info->cmd_win)), 1,
-			 file);
-		  if (ferror(file))
-		    ui_show_error("Error writing to file %s", filename);
-		  /* close file */
-		  fclose(file);
-		}
-	      else ui_show_error("Error opening file %s", filename);
-	      /* free memory */
-	      g_free((gpointer) filename);
-	    }
-	}
+      gchar *filename;
+      /* prompt user for file name */
+      filename = ui_get_file_name("Save SQL Buffer");
+      if (filename != NULL)
+        {
+          ui_save_text_to_file(GTK_TEXT(info->cmd_win), filename);
+          g_free((gpointer) filename);
+        }
     }
 }
 
@@ -228,6 +213,7 @@ sql_select_command (GtkWidget *w, gpointer data)
                                 GNOME_STOCK_BUTTON_OK,
                                 GNOME_STOCK_BUTTON_CANCEL,
                                 NULL);
+      gtk_widget_set_usize(dialog, 400, 400);
       gnome_dialog_set_default(GNOME_DIALOG(dialog), 0);              
       /* create scrolled window to put list inside */
       scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -262,7 +248,7 @@ sql_store_command (const gchar *cmd)
   if ((new_str = g_strdup(cmd)))
     {
       new_str = g_strstrip(new_str);
-      l_last_commands = g_list_append(l_last_commands, (gpointer) new_str);
+      l_last_commands = g_list_prepend(l_last_commands, (gpointer) new_str);
       if (g_list_length(l_last_commands) > MAX_COMMAND_LIST)
         {
           GList *node = g_list_first(l_last_commands);
