@@ -181,7 +181,7 @@ ui_new_text_in_table (GtkWidget *table, gint x1, gint y1, gint x2, gint y2)
   box = gtk_hbox_new(FALSE, 3);
   gtk_table_attach(GTK_TABLE(table), box, x1, x2, y1, y2,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   GTK_FILL | GTK_SHRINK,
+                   GTK_FILL | GTK_SHRINK | GTK_EXPAND,
                    3, 3);
   /* create text widget */
   text = gtk_text_new(NULL, NULL);
@@ -212,6 +212,43 @@ ui_new_toolbar_in_table (GtkWidget *table, gint x1, gint y1, gint x2, gint y2)
   return (toolbar);
 }
 
+gboolean
+ui_save_text_to_file (GtkText *text, gchar *filename)
+{
+  gchar *buffer;
+  /* check parameters */
+  g_return_val_if_fail(text != NULL, FALSE);
+  g_return_val_if_fail(filename != NULL, FALSE);
+  /* get text widget's contents */
+  buffer = gtk_editable_get_chars(GTK_EDITABLE(text), 0, gtk_text_get_length(text));
+  if (buffer != NULL)
+    {
+      FILE *file = fopen(filename, "w");
+      if (file != NULL)
+	{
+	  fwrite(buffer, gtk_text_get_length(text), 1,
+		 file);
+	  if (ferror(file))
+	    ui_show_error("Error writing to file %s", filename);
+	  /* close file */
+	  fclose(file);
+	}
+      else ui_show_error("Error opening file %s", filename);
+    }
+}
+
+void
+ui_set_notebook_page (GtkNotebook *notebook, GtkWidget *tab)
+{
+  gint current;
+  /* check parameters */
+  g_return_if_fail(notebook != NULL);
+  g_return_if_fail(tab != NULL);
+  /* activate the page by id */
+  current = gtk_notebook_page_num(notebook, tab);
+  gtk_notebook_set_page(notebook, current);
+}
+
 void
 ui_show_error (const gchar *format, ...)
 {
