@@ -211,7 +211,8 @@ gda_command_get_text(Gda_Command* cmd)
 
 
 #define ENUM_TO_STR(e) case (e): strncpy(bfr, #e, length); break
-static gchar* 
+
+gchar* 
 gda_gdatype_2_string(gchar* bfr, gint length, GDA_ValueType t)
 {
   if (!bfr)
@@ -291,7 +292,6 @@ gda_command_execute(Gda_Command* cmd, gulong* reccount, gulong flags)
   GList*                    ptr;
   GDA_CmdParameter*         corba_parameter;
   gint                      idx;
-  GDA_RowAttributes*        field_attributes;
   
   g_return_val_if_fail(cmd != NULL, 0);
   g_return_val_if_fail(cmd->text != NULL, 0);
@@ -338,10 +338,8 @@ gda_command_execute(Gda_Command* cmd, gulong* reccount, gulong flags)
 	  idx++;
 	}
     }
-  fprintf(stderr,"gda_command_execute: calling GDA_Command_execute\n");
   corba_rs = GDA_Command_execute(cmd->command, cmd->text, (CORBA_long*)&corba_reccount,
 				 corba_parameters, flags, &ev);
-  fprintf(stderr,"gda_command_execute: GDA_Command_execute returns %p\n", corba_rs);
   if (!corba_rs)
     return 0;
   *reccount = corba_reccount;
@@ -354,22 +352,24 @@ gda_command_execute(Gda_Command* cmd, gulong* reccount, gulong flags)
   rs->bof = 0;
   rs->open = 1;
 
-  field_attributes = GDA_Recordset_describe(corba_rs, &ev);
-  if (Exception(&ev) || field_attributes == CORBA_OBJECT_NIL)
+  rs->field_attributes = GDA_Recordset_describe(corba_rs, &ev);
+  if (Exception(&ev) || rs->field_attributes == CORBA_OBJECT_NIL)
     {
       fprintf(stderr," cannot get row description\n");
     }
-  for (idx = 0; idx  < field_attributes->_length; idx++)
+#if 0
+  for (idx = 0; idx  < rs->field_attributes->_length; idx++)
     {
       gchar type_bfr[120];
-      fprintf(stderr,"Description for field '%s'\n", field_attributes->_buffer[idx].name);
-      fprintf(stderr,"     defined Size   = %d\n", field_attributes->_buffer[idx].definedSize);
-      fprintf(stderr,"     scale          = %d\n", field_attributes->_buffer[idx].scale);
+      fprintf(stderr,"Description for field '%s'\n", rs->field_attributes->_buffer[idx].name);
+      fprintf(stderr,"     defined Size   = %d\n", rs->field_attributes->_buffer[idx].definedSize);
+      fprintf(stderr,"     scale          = %d\n", rs->field_attributes->_buffer[idx].scale);
       fprintf(stderr,"     gdaType        = '%s'\n", gda_gdatype_2_string(type_bfr, sizeof(type_bfr),
-									    field_attributes->_buffer[idx].gdaType));
-      fprintf(stderr,"     cType          = %d\n", field_attributes->_buffer[idx].cType);
-      fprintf(stderr,"     nativeType     = %d\n", field_attributes->_buffer[idx].nativeType);
+									    rs->field_attributes->_buffer[idx].gdaType));
+      fprintf(stderr,"     cType          = %d\n", rs->field_attributes->_buffer[idx].cType);
+      fprintf(stderr,"     nativeType     = %d\n", rs->field_attributes->_buffer[idx].nativeType);
     }
+#endif
   return rs;
 }
 
