@@ -70,6 +70,7 @@ get_corba_connection(Gda_Connection* cnc)
   if (!factory)
     {
       factory = goad_server_activate_with_id(NULL, cnc->provider, 0, NULL);
+      g_hash_table_insert(factories, cnc->provider, factory);
     }
   CORBA_exception_init(&ev);
   if (!factory)
@@ -358,6 +359,48 @@ gda_connection_close(Gda_Connection* cnc)
 }
 
 
+
+
+static Gda_Recordset*
+open_schema(Gda_Connection* cnc, GDA_Connection_QType t,
+	    GDA_Connection_ConstraintSeq* constraints)
+{
+  CORBA_Environment ev;
+  CORBA_Object      corba_rs;
+  Gda_Recordset*     rs;
+  gint               idx;
+  
+  CORBA_exception_init(&ev);
+
+  corba_rs = GDA_Connection_openSchema(cnc->connection, t,constraints, &ev);
+  if (Exception(&ev) < 0)
+    return 0;
+  rs = gda_recordset_new();
+  rs->eof = 0;
+  rs->bof = 0;
+  rs->open = 1;
+  rs->corba_rs = corba_rs;
+  rs->field_attributes = GDA_Recordset_describe(corba_rs, &ev);
+  if (Exception(&ev) || rs->field_attributes == CORBA_OBJECT_NIL)
+    {
+      fprintf(stderr," Cannot get recordset description\n");
+    }
+#if 0
+  for (idx = 0; idx  < rs->field_attributes->_length; idx++)
+    {
+      gchar type_bfr[120];
+      fprintf(stderr,"Description for field '%s'\n", rs->field_attributes->_buffer[idx].name);
+      fprintf(stderr,"     defined Size   = %d\n", rs->field_attributes->_buffer[idx].definedSize);
+      fprintf(stderr,"     scale          = %d\n", rs->field_attributes->_buffer[idx].scale);
+      fprintf(stderr,"     gdaType        = '%s'\n", gda_gdatype_2_string(type_bfr, sizeof(type_bfr),
+									    rs->field_attributes->_buffer[idx].gdaType));
+      fprintf(stderr,"     cType          = %d\n", rs->field_attributes->_buffer[idx].cType);
+      fprintf(stderr,"     nativeType     = %d\n", rs->field_attributes->_buffer[idx].nativeType);
+    }
+#endif
+  return rs;
+}
+
 /**
  * gda_connection_open_schema_array:
  * @cnc: Connection object
@@ -381,8 +424,6 @@ gda_connection_open_schema_array(Gda_Connection* cnc, GDA_Connection_QType t, Gd
   GDA_Connection_ConstraintSeq* constraints;
   gint                          count = 0;
   gint                          index;
-  Gda_Recordset*                rs;
-  CORBA_Object                  corba_rs;
   Gda_Constraint_Element*       current;
   
   g_return_val_if_fail(cnc != 0, 0);
@@ -415,15 +456,7 @@ gda_connection_open_schema_array(Gda_Connection* cnc, GDA_Connection_QType t, Gd
   fprintf(stderr,"client: gda_connection_open_schema: constraints._maximum = %d\n", constraints->_maximum);
   fprintf(stderr,"                                    constraints._length  = %d\n", constraints->_length);
   
-  corba_rs = GDA_Connection_openSchema(cnc->connection, t, constraints, &ev);
-  
-  if (Exception(&ev) < 0)
-    return 0;
-  rs = gda_recordset_new();
-  rs->eof = 0;
-  rs->bof = 0;
-  rs->corba_rs = corba_rs;
-  return rs;
+  return open_schema(cnc, t, constraints);
 }
 
 /**
@@ -454,8 +487,6 @@ gda_connection_open_schema(Gda_Connection* cnc, GDA_Connection_QType t, ...)
   GList*                        ptr;
   gint                          count = 0;
   gint                          index;
-  Gda_Recordset*                rs;
-  CORBA_Object                  corba_rs;
   
   g_return_val_if_fail(cnc != 0, 0);
   g_return_val_if_fail(cnc->connection != 0, 0);
@@ -491,22 +522,10 @@ gda_connection_open_schema(Gda_Connection* cnc, GDA_Connection_QType t, ...)
       ptr = g_list_next(ptr);
     }
   CORBA_exception_init(&ev);
-  fprintf(stderr,"client: gda_connection_open_schema: type                 = %d\n", t);
-  fprintf(stderr,"                                    constraints._maximum = %d\n", constraints->_maximum);
-  fprintf(stderr,"                                    constraints._length  = %d\n", constraints->_length);
-  
-  corba_rs = GDA_Connection_openSchema(cnc->connection, t, constraints, &ev);
-  g_warning("gda_connection_open_schema: Leaking Memory");
-  fprintf(stderr,"corba_rs = %p\n", corba_rs);
   /* @mla@ FIXME: free allocated storage */
-  if (corba_rs == CORBA_OBJECT_NIL || Exception(&ev) < 0)
-    return 0;
-  rs = gda_recordset_new();
-  rs->eof = 0;
-  rs->bof = 0;
-  rs->open = 1;
-  rs->corba_rs = corba_rs;
-  return rs;
+  g_warning("gda_connection_open_schema: Leaking ememory");
+  return open_schema(cnc, t, constraints);
+
 }
 
 /**
@@ -536,3 +555,46 @@ gda_connection_get_errors(Gda_Connection* cnc)
   return retval;
 }
 
+
+gint
+gda_connection_begin_transaction(Gda_Connection* cnc)
+{
+  CORBA_Environment ev;
+
+  CORBA_exception_init(&ev);
+  
+  GDA_Connection_beginTransaction(cnc->connection, &ev);
+  if (Exception(&ev) < 0)
+    return -1;
+  return 0;
+}
+
+
+gint
+gda_connection_commit_transaction(Gda_Connection* cnc)
+{
+  CORBA_Environment ev;
+
+  CORBA_exception_init(&ev);
+  
+  GDA_Connection_commitTransaction(cnc->connection, &ev);
+  if (Exception(&ev) < 0)
+    return -1;
+  return 0;
+  return 0;
+}
+
+
+gint
+gda_connection_rollback_transaction(Gda_Connection* cnc)
+{
+  CORBA_Environment ev;
+
+  CORBA_exception_init(&ev);
+  
+  GDA_Connection_rollbackTransaction(cnc->connection, &ev);
+  if (Exception(&ev) < 0)
+    return -1;
+  return 0;
+  return 0;
+}
