@@ -71,6 +71,9 @@ Gda_Recordset*              gda_connection_open_schema       (Gda_Connection* cn
 Gda_Recordset*              gda_connection_open_schema_array (Gda_Connection* cnc, GDA_Connection_QType t, Gda_Constraint_Element*);
 GList*                      gda_connection_get_errors        (Gda_Connection* cnc);
 GList*                      gda_connection_list_datasources  (Gda_Connection* cnc);
+gint                        gda_connection_begin_transaction (Gda_Connection* cnc);
+gint                        gda_connection_commit_transaction (Gda_Connection* cnc);
+gint                        gda_connection_rollback_transaction (Gda_Connection* cnc);
 
 
 /**
