@@ -199,7 +199,7 @@ value_2_ptr(GDA_Value* v)
       return &v->_u.dbtstamp;	/* struct SQLTIMESTAMP */
       break;
     case GDA_TypeDecimal:	
-      return v->_u.dec.value._buffer; /* unsigned char* */
+      return v->_u.lvc;		/* unsigned char* */
       break;
     case GDA_TypeDouble:
       return &v->_u.dp;		/* double */
@@ -285,7 +285,7 @@ value_2_inputsize(GDA_Value* v)
       return sizeof(v->_u.dbtstamp); /* struct SQLTIMESTAMP */
       break;
     case GDA_TypeDecimal:	
-      return v->_u.dec.value._length;		/* unsigned char* */
+      return SQL_NTS;		/* unsigned char* */
       break;
     case GDA_TypeDouble:
       return sizeof(v->_u.dp);		/* double */
@@ -332,7 +332,7 @@ value_2_inputsize(GDA_Value* v)
       
 
 Gda_ODBC_Recordset*
-gda_odbc_init_recset_for_hstmt(Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e)
+gda_odbc_describe_recset(Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e)
 {
   gint   rc;
   gshort ncols;
@@ -344,10 +344,7 @@ gda_odbc_init_recset_for_hstmt(Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e)
   rec->at_begin = 1;
   rec->pos = 0;
 
-  fprintf(stderr,"gda_odbc_init_recset_for_hstmt: entered, recset = 0x%p\n", rec);
-  fprintf(stderr,"gda_odbc_init_recset_for_hstmt: entered, recset->hstmt = 0x%p\n", rec->hstmt);
   rc = SQLNumResultCols(rec->hstmt, &ncols);
-  fprintf(stderr,"gda_odbc_init_recset_for_hstmt: number of columns: rc = %d, ncols = %d\n", rc, ncols);
   if (rc != SQL_SUCCESS)
     {
       gda_odbc_error_make(e, rec, rec->cmd->cnc , "SQLNumResultCols");
@@ -378,7 +375,7 @@ gda_odbc_init_recset_for_hstmt(Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e)
 	}
       colname[colnamelen] = '\0';
       f->name = g_strdup(colname);
-      fprintf(stderr,"gda_odbc_init_recset_for_hstmt: describing field '%s'\n", f->name);
+      fprintf(stderr,"gda_odbc_describe_recset: describing field '%s'\n", f->name);
       rec->fields = g_list_append(rec->fields, f);
     }
   return rec;
@@ -401,10 +398,6 @@ gda_odbc_cmd_execute(Gda_ODBC_Command* cmd, Gda_ODBC_Error* error, const GDA_Cmd
 
   recset = gda_odbc_recset_new();
   recset->hstmt = 0;
-  fprintf(stderr,"gda_odbc_cmd_execute: enter\n");
-  fprintf(stderr,"gda_odbc_cmd_execute: cmd = %p\n", cmd);
-  fprintf(stderr,"gda_odbc_cmd_execute: cmd->cnc = %p\n", cmd->cnc);
-  fprintf(stderr,"gda_odbc_cmd_execute: cmd->cnd->hdbc = %p\n", cmd->cnc->hdbc);
   
   rc = SQLAllocStmt(cmd->cnc->hdbc, &recset->hstmt);
   
@@ -415,7 +408,6 @@ gda_odbc_cmd_execute(Gda_ODBC_Command* cmd, Gda_ODBC_Error* error, const GDA_Cmd
       gda_odbc_recset_free(recset);
       return 0;
     }
-  fprintf(stderr,"gda_odbc_cmd_execute: recset->hstmt = %p\n", recset->hstmt);
 #if 0
   rc = SQLSetScrollOptions(recset->hstmt, SQL_CONCUR_ROWVER,  SQL_SCROLL_KEYSET_DRIVEN, 20);
   if (rc != SQL_SUCCESS)
@@ -450,8 +442,6 @@ gda_odbc_cmd_execute(Gda_ODBC_Command* cmd, Gda_ODBC_Error* error, const GDA_Cmd
 	  g_log("GDA ODBC", G_LOG_LEVEL_ERROR, "Statement doesn't need parameters, but params availble\n");
 	}
     }
-  fprintf(stderr,"Number of parameters from parser: %d\n", nparams);
-  fprintf(stderr,"Number od parameters from CORBA:  %d\n", params->_length);
   if (nparams)
     {
       
@@ -486,12 +476,6 @@ gda_odbc_cmd_execute(Gda_ODBC_Command* cmd, Gda_ODBC_Error* error, const GDA_Cmd
 	      return 0;
 	    }
 	  sizes[i] = value_2_inputsize(&current_parameter->value._u.v);
-	  fprintf(stderr,"gda_odbc_cmd_execute: before: sizes[%d] = %ld\n", i,
-		  sizes[i]);
-	  fprintf(stderr,"Calling SQLBindParameter for param %d\n", i+1);
-	  fprintf(stderr,"                            ctype = %ld\n", ctype);
-	  fprintf(stderr,"                          sqltype = %d\n", sqlType);
-	  
 	  rc = SQLBindParameter(recset->hstmt,
 				i + 1,
 				SQL_PARAM_INPUT,
@@ -525,7 +509,7 @@ gda_odbc_cmd_execute(Gda_ODBC_Command* cmd, Gda_ODBC_Error* error, const GDA_Cmd
       return 0;
     }
   recset->cmd = cmd;
-  return gda_odbc_init_recset_for_hstmt(recset, error);
+  return gda_odbc_describe_recset(recset, error);
 }
 
 
