@@ -60,6 +60,23 @@ static Gda_ODBC_Recordset*  schema_types(Gda_ODBC_Recordset*   recset,
 					 GDA_Connection_Constraint*  constraint,
 					 gint length);
 
+static Gda_ODBC_Recordset*  schema_views(Gda_ODBC_Recordset* recset,
+					 Gda_ODBC_Error*     e,
+					 Gda_ODBC_Connection* cnc,
+					 GDA_Connection_Constraint* constraint,
+					 gint length);
+
+static Gda_ODBC_Recordset*  schema_indexes(Gda_ODBC_Recordset* recset,
+					   Gda_ODBC_Error*     e,
+					   Gda_ODBC_Connection* cnc,
+					   GDA_Connection_Constraint* constraint,
+					   gint length);
+
+static Gda_ODBC_Recordset*  schema_procedures(Gda_ODBC_Recordset* recset,
+					      Gda_ODBC_Error*     e,
+					      Gda_ODBC_Connection* cnc,
+					      GDA_Connection_Constraint* constraint,
+					      gint length);
 
 static void
 initialize_schema_ops(void)
@@ -67,6 +84,9 @@ initialize_schema_ops(void)
   schema_ops[GDCN_SCHEMA_TABLES] = schema_tables;
   schema_ops[GDCN_SCHEMA_COLS]   = schema_columns;
   schema_ops[GDCN_SCHEMA_PROV_TYPES] = schema_types;
+  schema_ops[GDCN_SCHEMA_VIEWS] = schema_views;
+  schema_ops[GDCN_SCHEMA_INDEXES] = schema_indexes;
+  schema_ops[GDCN_SCHEMA_PROCS] = schema_procedures;
 }
 
 
@@ -113,9 +133,107 @@ schema_tables(Gda_ODBC_Recordset*   recset,
       SQLFreeStmt(recset->hstmt, SQL_DROP);
       return 0;
     }
-  return gda_odbc_init_recset_for_hstmt(recset, e);
+  return gda_odbc_describe_recset(recset, e);
 }
 
+static gint
+filter_views(Gda_ODBC_Recordset* in, gpointer data)
+{
+  GList*          field_ptr;
+  Gda_ODBC_Field* field;
+  gint            rc;
+  
+  field_ptr = g_list_nth(in->fields, 3);
+  field = field_ptr->data;
+  rc = strcmp(field->value->_u.lvc, "VIEW") == 0;
+  return rc;
+}
+
+
+static Gda_ODBC_Recordset*
+schema_views(Gda_ODBC_Recordset*   recset,
+	     Gda_ODBC_Error*       e,
+	     Gda_ODBC_Connection*  cnc,
+	     GDA_Connection_Constraint* constraints,
+	     gint length)
+{
+  gint                rc;
+  Gda_ODBC_Command*   cmd;
+  
+  cmd = gda_odbc_cmd_new();
+  cmd->cnc = cnc;
+  recset->cmd = cmd;
+  rc = SQLAllocStmt(cnc->hdbc, &recset->hstmt);
+  if (rc != SQL_SUCCESS)
+    {
+      fprintf(stderr,"SQLAllocStmt failed\n");
+      return 0;
+    }
+  rc = SQLTables(recset->hstmt,
+		 "", SQL_NTS,
+		 "", SQL_NTS,
+		 "", SQL_NTS,
+		 "", SQL_NTS);
+  if (rc != SQL_SUCCESS)
+    {
+      gda_odbc_error_make(gda_odbc_error_new(),
+			  recset,
+			  cnc,
+			  "SQLTables");
+      SQLFreeStmt(recset->hstmt, SQL_DROP);
+      return 0;
+    }
+  recset->internal_filter_function = filter_views;
+  return gda_odbc_describe_recset(recset, e);
+}
+
+static Gda_ODBC_Recordset*
+schema_indexes(Gda_ODBC_Recordset*   recset,
+	     Gda_ODBC_Error*       e,
+	     Gda_ODBC_Connection*  cnc,
+	     GDA_Connection_Constraint* constraints,
+	     gint length)
+{
+  return 0;
+}
+
+static Gda_ODBC_Recordset*
+schema_procedures(Gda_ODBC_Recordset*   recset,
+		  Gda_ODBC_Error*       e,
+		  Gda_ODBC_Connection*  cnc,
+		  GDA_Connection_Constraint* constraints,
+		  gint length)
+{
+  Gda_ODBC_Command* cmd;
+  gint              rc;
+  
+  cmd = gda_odbc_cmd_new();
+  cmd->cnc = cnc;
+  recset->cmd = cmd;
+  rc = SQLAllocStmt(cnc->hdbc, &recset->hstmt);
+  if (rc != SQL_SUCCESS)
+    {
+      fprintf(stderr,"SQLAllocStmt failed\n");
+      return 0;
+    }
+  rc = SQLProcedures(recset->hstmt,
+		     "", SQL_NTS, /* proc Qualifier */
+		     "", SQL_NTS, /* proc Owner  */
+		     "", SQL_NTS); /* proc Name */
+  if (rc != SQL_SUCCESS)
+    {
+      gda_odbc_error_make(gda_odbc_error_new(),
+			  recset,
+			  cnc,
+			  "SQLProcedures");
+      SQLFreeStmt(recset->hstmt, SQL_DROP);
+      recset->hstmt = 0;
+      return 0;
+    }
+  return gda_odbc_describe_recset(recset, e);
+}
+
+
 
 static Gda_ODBC_Recordset*
 schema_columns(Gda_ODBC_Recordset*  recset,
@@ -181,8 +299,7 @@ schema_columns(Gda_ODBC_Recordset*  recset,
       SQLFreeStmt(recset->hstmt, SQL_DROP);
       return 0;
     }
-  fprintf(stderr,"schema_columns: calling gda_odbc_init_recset_for_hstmt\n");
-  return gda_odbc_init_recset_for_hstmt(recset, e);
+  return gda_odbc_describe_recset(recset, e);
 }
 
 static Gda_ODBC_Recordset*
@@ -208,7 +325,7 @@ schema_types(Gda_ODBC_Recordset*   recset,
       SQLFreeStmt(recset->hstmt, SQL_DROP);
       return 0;
     }
-  return gda_odbc_init_recset_for_hstmt(recset, e);
+  return gda_odbc_describe_recset(recset, e);
 }
 
 
