@@ -3,6 +3,7 @@
 #include <stdio.h>
 #include <signal.h>
 #include <gnome.h>
+#include <libgnorba/gnorba.h>
 
 #include "odbc.h"
 #include "sqldriver.h"
@@ -44,7 +45,6 @@ gda_ConnectionFactory_create(PortableServer_Servant _obj,
   GDAConnectionFactory_Servant* cf_servant = (GDAConnectionFactory_Servant*)_obj;
   PortableServer_ObjectId*      oid;
   
-  fprintf(stderr,"gda_ConnectionFactory_create: called\n");
   new_connection_servant = g_new0(GDAConnection_Servant, 1);
   new_connection_servant->base._private = 0;
   new_connection_servant->base.vepv     = &poa_gda_connection__vepv;
@@ -59,7 +59,7 @@ gda_ConnectionFactory_create(PortableServer_Servant _obj,
 
   new_connection = PortableServer_POA_servant_to_reference(cf_servant->poa, (PortableServer_Servant)new_connection_servant, ev);
   Exception(ev);
-  fprintf(stderr,"gda_ConnectionFactory_create: left\n");
+
   return new_connection;
 }
 
@@ -72,7 +72,6 @@ gda_Connection_open(PortableServer_Servant _obj,
 {
   GDAConnection_Servant* cnc = (GDAConnection_Servant*) _obj;
 
-  fprintf(stderr,"gda_Connection_open enter\n");
   if (gda_odbc_connection_open(cnc->cnc, dsn, user, passwd) < 0)
     {
       fprintf(stderr,"gda_Connection_open Errr left\n");
@@ -80,7 +79,6 @@ gda_Connection_open(PortableServer_Servant _obj,
     }
   else
     {
-      fprintf(stderr,"gda_Connection_open OK left\n");
       return 0;
     }
 }
@@ -143,8 +141,6 @@ gda_Connection_openSchema   (PortableServer_Servant _obj,
   PortableServer_ObjectId* oid;
   Gda_ODBC_Error           e;
   
-  fprintf(stderr,"gda_Connection_openSchema: constraints->_length = %d\n", constraints->_length);
-  fprintf(stderr,"gda_Connection_openSchema: constraints->_maximum = %d\n", constraints->_maximum);
   memset(&e, '\0', sizeof(e));
   if ((recset = gda_odbc_connection_open_schema(cnc->cnc, &e, t, constraints->_buffer, constraints->_length)) == 0)
     {
@@ -179,13 +175,24 @@ gda_Connection_close(PortableServer_Servant _obj,
 {
   GDAConnection_Servant* cnc = (GDAConnection_Servant*) _obj;
   PortableServer_POA     poa = cnc->poa;
+  GDA_Connection         old_connection;
+
+  
+  old_connection = PortableServer_POA_servant_to_reference(cnc->poa,
+							   (PortableServer_Servant)cnc, env);
+  Exception(env);
   
   if (gda_odbc_connection_close(cnc->cnc) < 0)
-    return -1;
+    {
+      fprintf(stderr," gda_odbc_connection_close returns an error\n");
+      return -1;
+    }
   PortableServer_POA_deactivate_object(poa,
 				       PortableServer_POA_servant_to_id(poa,cnc, env),
 				       env);
   Exception(env);
+  POA_GDA_Connection__fini((POA_GDA_Connection*)cnc, env);
+  Exception(env);
   return 0;
 }
 
@@ -234,7 +241,6 @@ gda_Command_execute(PortableServer_Servant _obj,
   PortableServer_ObjectId* oid;
   Gda_ODBC_Error*          error;
   
-  fprintf(stderr,"gda_Command_execute: cmd = '%s'\n", cmd);
   if (command_servant->cmd->cmd) {
     fprintf(stderr,"WARNING WARNING: command string still existing\n");
     g_free(command_servant->cmd->cmd);
@@ -286,20 +292,17 @@ GDA_odbc_recset_close(PortableServer_Servant _obj,
   GDARecordset_Servant*  rs = (GDARecordset_Servant*) _obj;
   PortableServer_POA     poa = rs->poa;
 
-  fprintf(stderr,"GDA_odbc_recset_close: closing recordset\n");
   if (gda_odbc_recset_close(rs->recset) < 0)
     {
       fprintf(stderr,"GDA_odbc_recset_close: error during close\n");
       return -1;
     }
-  fprintf(stderr,"GDA_odbc_recset_close: NOT deactivating object\n");
-#if 0
   PortableServer_POA_deactivate_object(poa,
 				       PortableServer_POA_servant_to_id(poa,rs, env),
 				       env);
   Exception(env);
-#endif
-  fprintf(stderr,"GDA_odbc_recset_close: left\n");
+  POA_GDA_Recordset__fini((POA_GDA_Recordset*)rs, env);
+  Exception(env);
   return 0;
 }
 
@@ -326,6 +329,7 @@ gda_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environmen
       chunk->_buffer[rowidx]._length = 0;
       chunk->_buffer[rowidx]._buffer = 0;
     }
+  
   rowidx = 0;
   
   do {
@@ -341,7 +345,6 @@ gda_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environmen
       while(ptr)
 	{
 	  field->realValue._d = 1;
-	  field->name = 0;
 	  server_field = ptr->data;
 	  server_field->value = &field->realValue._u.v;
 	  server_field->value->_u.lvc = 0;
@@ -364,19 +367,11 @@ gda_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environmen
       while(ptr)
 	{
 	  server_field = ptr->data;
-	  
-	  field->name         = CORBA_string_dup(server_field->name);
 	  field->actualSize   = server_field->actual_length;
-	  field->definedSize  = server_field->defined_length;
-	  field->scale        = server_field->num_scale;
-	  field->precission   = server_field->precission;
-	  field->gdaType      = server_field->value->_d;
-	  field->cType        = server_field->c_type;
-	  field->nativeType   = server_field->sql_type;
 	  field->realValue._d = server_field->actual_length == SQL_NULL_DATA;
 	  field->shadowValue._d   = 1;
 	  field->originalValue._d = 1;
-	  if (field->cType == SQL_C_BINARY)
+	  if (field->realValue._u.v._d == GDA_TypeBinary)
 	    {
 	      fprintf(stderr, "         field->rv._u.v._u.lvb._maximum = %d\n", field->realValue._u.v._u.lvb._maximum);
 	      if (field->actualSize == -1)
@@ -390,31 +385,11 @@ gda_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environmen
 	      else
 		field->realValue._u.v._u.lvb._length = field->actualSize;
 	    }
-#if 0
-	  printf("Values for field '%s'\n", field->name);
-	  printf("        field->actualSize = %d\n", field->actualSize);
-	  if (field->cType == SQL_C_BINARY)
-	    {
-	      printf("         field->rv._u.v._u.lvb._length  = %d\n", field->realValue._u.v._u.lvb._length);
-	      printf("         field->rv._u.v._u.lvb._maximum = %d\n", field->realValue._u.v._u.lvb._maximum);
-	    }
-	  printf("        field->definedSize = %d\n", field->definedSize);
-	  printf("        field->scale       = %d\n", field->scale);
-	  printf("        field->precission  = %d\n", field->precission);
-	  printf("        field->gdaType     = %d\n", field->gdaType);
-	  printf("        field->c_type      = %d\n", field->cType);
-	  
-	  printf("        field->nativeType  = %d\n", field->nativeType);
-	  printf("        field->realVal._d  = %d\n", field->realValue._d);
-	  printf("        field->rv._u.v._d  = %d\n", field->realValue._u.v._d);
-	  printf("        field->rv._u.v._u.ll = %Ld\n", field->realValue._u.v._u.ll);
-#endif
 	  ptr = g_list_next(ptr);
 	  field = &row->_buffer[++colidx];
 	}
       rowidx++;
   }while (rowidx < count);
-  printf("gda_Recset_fetch: count = %d, rowidx = %d, fetchresult = %d\n", count, rowidx, rc);
   chunk->_length = rowidx;
   return chunk;
 }
@@ -430,8 +405,6 @@ gda_Recset_describe(PortableServer_Servant _obj, CORBA_Environment* ev)
   GDA_FieldAttributes*   field;
   gint                   idx;
 
-  fprintf(stderr,"gda_Recset_describe called\n");
-  
   rc = GDA_RowAttributes__alloc();
   rc->_length = g_list_length(rs->fields);
   fprintf(stderr,"gda_Recset_describe: length = %d\n", rc->_length);
@@ -469,6 +442,7 @@ connection_factory__create  (PortableServer_POA poa,   gpointer *impl_ptr,  CORB
   servant->base._private = NULL;
   servant->base.vepv     = &poa_gda_connectionfactory__vepv;
   servant->poa           = poa;
+
   POA_GDA_ConnectionFactory__init((PortableServer_Servant)servant, ev);
   objid = PortableServer_POA_activate_object(poa, servant, ev);
   CORBA_free(objid);
@@ -532,5 +506,5 @@ GDA_Connection_DSNlist* gda_Connection_listSources(PortableServer_Servant _obj,
 void
 connection_factory__destroy (PortableServer_POA poa,   gpointer impl_ptr,   CORBA_Environment *ev)
 {
-  ;
+  fprintf(stderr,"connection_factory__destroy called\n");
 }
