@@ -21,15 +21,20 @@
 #include "odbc.h"
 #include "gda.h"
 
+struct _Gda_ODBC_Recordset;
+
+typedef  gint   (*GDA_Filter_Function)            (struct _Gda_ODBC_Recordset* in, gpointer data);
+
 typedef struct _Gda_ODBC_Recordset
 {
   struct _Gda_ODBC_Command*  cmd;
-  gint                  auto_cmd;
-  gint                  at_begin;
-  gint                  at_end;
-  gulong                pos;
-  GList*                fields;
-  HSTMT                 hstmt;
+  GDA_Filter_Function        internal_filter_function;
+  gint                       auto_cmd;
+  gint                       at_begin;
+  gint                       at_end;
+  gulong                     pos;
+  GList*                     fields;
+  HSTMT                      hstmt;
 }Gda_ODBC_Recordset;
 
 
