@@ -65,7 +65,7 @@ main(int argc, char* argv[])
   Gda_Connection*    cnc;
   Gda_Recordset*     rs;
   gulong             position;
-  GDA_Field*         field = 0;
+  Gda_Field*         field = 0;
   gchar              vbfr[255];
   gint               fieldidx;
   gint               row = 0;
@@ -112,7 +112,7 @@ main(int argc, char* argv[])
     {
       field = gda_recordset_field_idx(rs, fieldidx);
 	{
-	  printf("%15.15s ", field->name);
+	  printf("%15.15s ", field->attributes->name);
 	}
     }
   printf("\n");
